==> haskell-hw-hspec-hedgehog-0.1.1.1-205.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-hspec-hedgehog
version:              0.1.1.1
visibility:           public
id:                   hw-hspec-hedgehog-0.1.1.1-GFD3arrJAsKDm17Q3uXVY3
key:                  hw-hspec-hedgehog-0.1.1.1-GFD3arrJAsKDm17Q3uXVY3
license:              BSD-3-Clause
copyright:            2017-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
homepage:             https://github.com/haskell-works/hw-hspec-hedgehog#readme
synopsis:             Interoperability between hspec and hedgehog
description:          Interoperability between hspec and hedgehog.
category:             Test
abi:                  6461eaee70cfd7d8391cfe74c355cfd9
exposed:              True
exposed-modules:      HaskellWorks.Hspec.Hedgehog
hidden-modules:       Paths_hw_hspec_hedgehog
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hw-hspec-hedgehog-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-hspec-hedgehog
hs-libraries:         HShw-hspec-hedgehog-0.1.1.1-GFD3arrJAsKDm17Q3uXVY3
depends:
    HUnit-1.6.2.0-IE0oFrOTEOHIkscEaBk8om base-4.18.2.1
    call-stack-0.4.0-6YsJqSpqGk4Bu2nGz8R6vi
    hedgehog-1.5-1xA9En5y6Uc9YP36VbJg3a
    hspec-2.11.4-2r49l9VEKrJ4fH7w2ReGM6 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hw-hspec-hedgehog/html/hw-hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hw-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hw-hspec-hedgehog-0.1.1.1-206-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hw-hspec-hedgehog.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hw-hspec-hedgehog
version:              0.1.1.1
visibility:           public
id:                   hw-hspec-hedgehog-0.1.1.1-3PiqRyptCc03O3u15zzHMj
key:                  hw-hspec-hedgehog-0.1.1.1-3PiqRyptCc03O3u15zzHMj
license:              BSD-3-Clause
copyright:            2017-2021 John Ky
maintainer:           newhoggy@gmail.com
author:               John Ky
homepage:             https://github.com/haskell-works/hw-hspec-hedgehog#readme
synopsis:             Interoperability between hspec and hedgehog
description:          Interoperability between hspec and hedgehog.
category:             Test
abi:                  426785728773c81c51d9ca34142bb5be
exposed:              True
exposed-modules:      HaskellWorks.Hspec.Hedgehog
hidden-modules:       Paths_hw_hspec_hedgehog
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hw-hspec-hedgehog-0.1.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hw-hspec-hedgehog-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hw-hspec-hedgehog
hs-libraries:         HShw-hspec-hedgehog-0.1.1.1-3PiqRyptCc03O3u15zzHMj
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA base-4.18.2.1
    call-stack-0.4.0-2bP2isqo6m56I7hpBeHX0O
    hedgehog-1.5-BwlqoHTHZqU94Z0NM4guvO
    hspec-2.11.4-8QgnQwrEho14jh62SRkWei transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hw-hspec-hedgehog/html/hw-hspec-hedgehog.haddock

haddock-html:         /usr/share/doc/haskell-hw-hspec-hedgehog/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
